transit-chem
============


.. image:: https://img.shields.io/pypi/v/transit_chem.svg
        :target: https://pypi.python.org/pypi/transit_chem

.. image:: https://img.shields.io/travis/ecurtin2/transit-chem.svg
        :target: https://travis-ci.org/ecurtin2/transit-chem

.. image:: https://readthedocs.org/projects/transit-chem/badge/?version=latest
        :target: https://transit-chem.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Quantifying electron transit in donor-bridge-acceptor systems using probabilistic confidence.


* Free software: MIT license
* Documentation: https://transit-chem.readthedocs.io.


Features
--------

* TODO

Credits
-------

Cookiecutter: https://github.com/audreyr/cookiecutter
audreyr/cookiecutter-pypackage: https://github.com/audreyr/cookiecutter-pypackage
Setup.py: https://github.com/kennethreitz/setup.py/blob/master/setup.py
